class: Workflow
cwlVersion: cwl:draft-3
hints:
- class: DockerRequirement
  dockerImageId: bcbio/bcbio
  dockerPull: bcbio/bcbio
inputs:
- id: '#files'
  type:
    items: File
    type: array
- id: '#config__algorithm__align_split_size'
  type: long
- id: '#config__algorithm__aligner'
  type: string
- id: '#description'
  type: string
- id: '#reference__fasta__base'
  type: File
- id: '#rgnames__pl'
  type: string
- id: '#rgnames__sample'
  type: string
- id: '#rgnames__pu'
  type: string
- id: '#rgnames__lane'
  type: string
- id: '#rgnames__rg'
  type: string
- id: '#rgnames__lb'
  type: 'null'
- id: '#reference__snap__indexes'
  type: File
- id: '#config__algorithm__mark_duplicates'
  type: string
outputs:
- id: '#align_bam'
  secondaryFiles:
  - .bai
  source: '#merge_split_alignments.align_bam'
  type: File
- id: '#work_bam-plus__disc'
  secondaryFiles:
  - .bai
  source: '#merge_split_alignments.work_bam-plus__disc'
  type: File
- id: '#work_bam-plus__sr'
  secondaryFiles:
  - .bai
  source: '#merge_split_alignments.work_bam-plus__sr'
  type: File
- id: '#hla__fastq'
  source: '#merge_split_alignments.hla__fastq'
  type:
  - File
  - 'null'
requirements:
- class: EnvVarRequirement
  envDef:
  - envName: MPLCONFIGDIR
    envValue: .
- class: ScatterFeatureRequirement
- class: StepInputExpressionRequirement
- class: SubworkflowFeatureRequirement
- class: InlineJavascriptRequirement
steps:
- id: '#prep_align_inputs'
  inputs:
  - id: '#prep_align_inputs.files'
    source: '#files'
  - id: '#prep_align_inputs.config__algorithm__align_split_size'
    source: '#config__algorithm__align_split_size'
  - id: '#prep_align_inputs.config__algorithm__aligner'
    source: '#config__algorithm__aligner'
  - id: '#prep_align_inputs.description'
    source: '#description'
  outputs:
  - id: '#prep_align_inputs.files'
  - id: '#prep_align_inputs.config__algorithm__quality_format'
  - id: '#prep_align_inputs.align_split'
  run: steps/prep_align_inputs.cwl
- id: '#process_alignment'
  inputs:
  - id: '#process_alignment.files'
    source: '#prep_align_inputs.files'
  - id: '#process_alignment.reference__fasta__base'
    source: '#reference__fasta__base'
  - id: '#process_alignment.rgnames__pl'
    source: '#rgnames__pl'
  - id: '#process_alignment.rgnames__sample'
    source: '#rgnames__sample'
  - id: '#process_alignment.rgnames__pu'
    source: '#rgnames__pu'
  - id: '#process_alignment.rgnames__lane'
    source: '#rgnames__lane'
  - id: '#process_alignment.rgnames__rg'
    source: '#rgnames__rg'
  - id: '#process_alignment.rgnames__lb'
    source: '#rgnames__lb'
  - id: '#process_alignment.reference__snap__indexes'
    source: '#reference__snap__indexes'
  - id: '#process_alignment.config__algorithm__aligner'
    source: '#config__algorithm__aligner'
  - id: '#process_alignment.config__algorithm__mark_duplicates'
    source: '#config__algorithm__mark_duplicates'
  - id: '#process_alignment.description'
    source: '#description'
  outputs:
  - id: '#process_alignment.work_bam'
  - id: '#process_alignment.align_bam'
  - id: '#process_alignment.hla__fastq'
  - id: '#process_alignment.work_bam-plus__disc'
  - id: '#process_alignment.work_bam-plus__sr'
  run: steps/process_alignment.cwl
  scatter:
  - '#process_alignment.files'
  scatterMethod: dotproduct
- id: '#merge_split_alignments'
  inputs:
  - id: '#merge_split_alignments.work_bam'
    source: '#process_alignment.work_bam'
  - id: '#merge_split_alignments.align_bam'
    source: '#process_alignment.align_bam'
  - id: '#merge_split_alignments.work_bam-plus__disc'
    source: '#process_alignment.work_bam-plus__disc'
  - id: '#merge_split_alignments.work_bam-plus__sr'
    source: '#process_alignment.work_bam-plus__sr'
  - id: '#merge_split_alignments.hla__fastq'
    source: '#process_alignment.hla__fastq'
  - id: '#merge_split_alignments.description'
    source: '#description'
  outputs:
  - id: '#merge_split_alignments.align_bam'
  - id: '#merge_split_alignments.work_bam-plus__disc'
  - id: '#merge_split_alignments.work_bam-plus__sr'
  - id: '#merge_split_alignments.hla__fastq'
  run: steps/merge_split_alignments.cwl
